#
# spec file for package python3-gunicorn
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-gunicorn
Version:        19.3.0
Release:        3.6
Summary:        WSGI HTTP Server for UNIX
License:        MIT
Group:          Development/Languages/Python
Url:            http://gunicorn.org
Source:         http://pypi.python.org/packages/source/g/gunicorn/gunicorn-%{version}.tar.gz
BuildRequires:  python3-Sphinx
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-distribute
BuildRequires:  python3-nose
#BuildRequires:	python3-pytest
BuildRequires:  fdupes
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Gunicorn 'Green Unicorn' is a Python WSGI HTTP Server for UNIX. It's a pre-fork
worker model ported from Ruby's Unicorn_ project. The Gunicorn server is broadly
compatible with various web frameworks, simply implemented, light on server
resource usage, and fairly speedy.

%package        doc
Summary:        WSGI HTTP Server for UNIX - Documentation
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
This package contains Gunicorn documentation in reST and HTML formats.

%prep
%setup -q -n gunicorn-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
cd docs && make SPHINXBUILD=sphinx-build html && rm -r build/html/.buildinfo # Generate HTML documentation
%fdupes -s build/html
%fdupes -s examples

mv %{buildroot}%{_bindir}/gunicorn_paster %{buildroot}%{_bindir}/gunicorn_paster-python%{py3_ver}
mv %{buildroot}%{_bindir}/gunicorn_django %{buildroot}%{_bindir}/gunicorn_django-python%{py3_ver}
mv %{buildroot}%{_bindir}/gunicorn %{buildroot}%{_bindir}/gunicorn-python%{py3_ver}

#%check
#python3 setup.py test

%files
%defattr(-,root,root,-)
%doc LICENSE NOTICE README.rst THANKS
%{_bindir}/gunicorn*
%{python3_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc docs/build/html examples

%changelog
* Mon Jun 29 2015 toddrme2178@gmail.com
- Use python3-Sphinx instead of python-Sphinx
* Fri Mar  6 2015 arun@gmx.de
- update to version 19.3.0:
  * Core
    + fix: issue 978 make sure a listener is inheritable
    + add check_config class method to workers
    + fix: issue 983 fix select timeout in sync worker with multiple connections
    + allows workers to access to the reloader. close issue 984
    + raise TypeError instead of AssertionError
  * Logging
    + make Logger.loglevel a classs attribute
  * Documentation
    + fix: issue 988 fix syntax errors in examples/gunicorn_rc
* Wed Feb  4 2015 arun@gmx.de
- update to version 19.2.1:
  * expose loglevel in the Logger class
  * fix :issue: "977" fix initial crash
  * document security mailing-list in the contributing page.
* Sat Jan 31 2015 arun@gmx.de
- update to version 19.2.0:
  * optimize the sync workers when listening on a single interface
  * add --sendfile settings to enable/disable sendfile. fix issue:856
  * add the selectors module to the code base. issue:886
  * add --max-requests-jitter setting to set the maximum jitter to add
    to the max-requests setting.
  * fix issue:899 propagate proxy_protocol_info to keep-alive requests
  * fix issue:863 worker timeout: dynamic timeout has been removed
  * fix: Avoid world writable file
  * fix issue:941 set logconfig default to paster more trivially
  * add statsd-prefix config setting: set the prefix to use when
    emitting statsd metrics
  * issue:832 log to console by default
  * fix :issue:`908` make sure the worker can continue to accept
    requests
  * fix issue:867 Fix eventlet shutdown to actively shut down the
    workers.
* Fri Jan 16 2015 arun@gmx.de
- specfile: update copyright year
- update to version 19.1.1
  * fix :issue:`835`: display correct pid of already running instance
  * fix :pr:`833`: fix PyTest class in setup.py.
  * fix :issue:`838`: statsd logger, send statsd timing metrics in
    milliseconds
  * fix :issue:`839`: statsd logger, allows for empty log message
    while pushing metrics and restore worker number in DEBUG logs
  * fix :issue:`850`: add timezone to logging
  * fix :issue:`853`: Respect logger_class setting unless statsd is on
  * fix :issue:`830` make sure gaiohttp worker is shipped with
    gunicorn.
- changes from version 19.1:
  * fix :issue:`785`: handle binary type address given to a client
    socket address
  * fix graceful shutdown. make sure QUIT and TERMS signals are
    switched everywhere.
  * :issue:`799`: fix support loading config from module
  * :issue:`805`: fix check for file-like objects
  * fix :issue:`815`: args validation in WSGIApplication.init
  * fix :issue:`787`: check if we load a pyc file or not.
  * fix :issue:`771`: support tornado 4.0
  * fix :issue:`783`: x_headers error. The x-forwarded-headers option
    has been removed in c4873681299212d6082cd9902740eef18c2f14f1. The
    discussion is available on :pr:`633`.
  * fix: fetch all body in input. fix :issue:`803`
  * fix: don't install the worker if python < 3.3
  * fix :issue:`822`: Support UNIX sockets in gaiohttp worker
  * fix :issue:`790`: StopIteration shouldn't be catched at this
    level.
  * add statsd logging handler fix :issue:`748`
  * fix :issue:`809`: Set global logging configuration from a Paste
    config.
  * fix RuntimeError in gunicorn.reloader (:issue:`807`)
  * update faq: put a note on how watch logs in the console since many
    people asked for it.
- changes from version 19.0:
  * Switch QUIT and TERM signals
  * add aiohttp worker named gaiohttp using asyncio. Full async worker
    on python 3.
  * fix HTTP-violating excess whitespace in write_error output
  * fix: try to log what happened in the worker after a timeout, add a
    worker_abort hook on SIGABRT signal.
  * fix: save listener socket name in workers so we can handle
    buffered keep-alive requests after the listener has closed.
  * add on_exit hook called just before exiting gunicorn.
  * add support for python 3.4
  * fix: do not swallow unexpected errors when reaping
  * fix: remove incompatible SSL option with python 2.6
  * add new async gthread worker and --threads options allows to set
    multiple threads to listen on connection
  * deprecate gunicorn_django and gunicorn_paster
  * switch QUIT and TERM signal
  * reap workers in SIGCHLD handler
  * add universal wheel support
  * use email.utils.formatdate in gunicorn.util.http_date
  * deprecate the --debug option
  * fix: log exceptions that occur after response start
  * allows loading of applications from .pyc files (#693)
  * fix: issue #691, raw_env config file parsing
  * use a dynamic timeout to wait for the optimal time. (Reduce power
    usage)
  * fix python3 support when notifying the arbiter
  * add: honor $WEB_CONCURRENCY environment variable. Useful for
    heroku setups.
  * add: include tz offset in access log
  * add: include access logs in the syslog handler.
  * add --reload option for code reloading
  * add the capability to load gunicorn.base.Application without the
    loading of the arguments of the command line. It allows you to
    :ref:`embed gunicorn in your own application <custom>`.
  * improve: set wsgi.multithread to True for async workers
  * fix logging: make sure to redirect wsgi.errors when needed
  * add: syslog logging can now be done to a unix socket
  * fix logging: don't try to redirect stdout/stderr to the logfile.
  * fix logging: don't propagate log
  * improve logging: file option can be overriden by the gunicorn
    options --error-logfile and --access-logfile if they are given.
  * fix: don't override SERVER_* by the Host header
  * fix: handle_error
  * add more option to configure SSL
  * fix: sendfile with SSL
  * add: worker_int callback (to react on SIGTERM)
  * fix: don't depend on entry point for internal classes, now
    absolute modules path can be given.
  * fix: Error messages are now encoded in latin1
  * fix: request line length check
  * improvement: proxy_allow_ips: Allow proxy protocol if "*"
    specified
  * fix: run worker's setup method before setting num_workers
  * fix: FileWrapper inherit from object now
  * fix: Error messages are now encoded in latin1
  * fix: don't spam the console on SIGWINCH.
  * fix: logging -don't stringify T and D logging atoms (#621)
  * add support for the latest django version
  * deprecate run_gunicorn django option
  * fix: sys imported twice
  * fix: make sure to stop all listeners
  * fix: monkey patching is now done in the worker
  * fix: "global name 'hub' is not defined"
  * fix: reinit hub on old versions of gevent
  * support gevent 1.0
  * fix: add subprocess in monkey patching
  * fix: add support for multiple listener
  * fix: merge duplicate EventletWorker.init_process method (fixes
    [#657])
  * fix: missing errno import for eventlet sendfile patch
  * fix: add support for multiple listener
  * add graceful stop support
- changes from version 18.0:
  * new: add -e/--env command line argument to pass an environment
    variables to gunicorn
  * new: add --chdir command line argument to specified directory
    before apps loading. - new: add wsgi.file_wrapper support in async
    workers
  * new: add --paste command line argument to set the paster config
    file
  * deprecated: the command gunicorn_django is now deprecated. You
    should now run your application with the WSGI interface installed
    with your project (see
    https://docs.djangoproject.com/en/1.4/howto/deployment/wsgi/gunicorn/)
    for more infos.
  * deprecated: the command gunicorn_paste is deprecated. You now
    should use the new --paste argument to set the configuration file
    of your paster application.
  * fix: Removes unmatched leading quote from the beginning of the
    default access log format string
  * fix: null timeout
  * fix: gevent worker
  * fix: don't reload the paster app when using pserve
  * fix: after closing for error do not keep alive the connection
  * fix: responses 1xx, 204 and 304 should not force the connection to
    be closed
- changes from version 17.5:
  * new: add signals documentation
  * new: add post_worker_init hook for workers
  * new: try to use gunicorn.conf.py in current folder as the default
    config file.
  * fix graceful timeout with the Eventlet worker
  * fix: don't raise an error when closing the socket if already
    closed
  * fix: fix --settings parameter for django application and try to
    find the django settings when using the gunicorn command.
  * fix: give the initial global_conf to paster application
  * fix: fix 'Expect: 100-continue' support on Python 3
- changes from version 0.17.4:
  * fix unix socket address parsing
- changes from version 0.17.3:
  * add systemd sockets support
  * add python -m gunicorn.app.wsgiapp support
  * improve logger class inheritance
  * exit when the config file isn't found
  * add the -R option to enable stdio inheritance in daemon mode
  * don't close file descriptors > 3 in daemon mode
  * improve STDOUT/STDERR logging
  * fix pythonpath option
  * fix pidfile creation on Python 3
  * fix gevent worker exit
  * fix ipv6 detection when the platform isn't supporting it
* Mon Jan 14 2013 p.drouand@gmail.com
- Initial python3 support
